// SelectionInfo.h : interface for TSelectionInfo class
//

#pragma once

#include "Utils/Collections.h"

#undef DECL
#if defined(NOT_XPERT)
#define DECL
#else
#if defined(_AFXDLL) || defined(XPERT_EXE)
#ifdef UTILS_DLL
#define DECL _declspec(dllexport)
#else
#define DECL _declspec(dllimport)
#endif
#else
#define DECL 
#endif
#endif

/*
   TSelectionInfo can be created to attach a selection to a TProperty

   This is typically a global structure meant to be shared by multiple
   instances of properties.

   set the bStoreIndex flag to true if the property contains the index
   of the selection (0, 1, 2, etc), and not the selection itself ("deg C", "deg F").

   a SaveFile may be specified to cause the list to be saved/loaded from disk.

   you may allow the user to edit the selection by setting bAllowEdit to true.

   if you wish to keep the list in sorted order set bKeepSorted to true, but
   this shouldn't be used with bStoreIndex==true because the index values will
   get scrambled.

*/
class DECL TSelectionInfo
{
public:
   TSelectionInfo(const CString& strSaveFileName=_T(""), bool bAllowEdit=true, bool bKeepSorted=true, bool bNumeric=false, bool bStoreIndex=false)
   { strSaveFile=strSaveFileName; AllowEdit=bAllowEdit; KeepSorted=bKeepSorted; Numeric=bNumeric; StoreIndex=bStoreIndex; };
   TSelectionInfo(LPCTSTR tstrs[], int iCount, const CString& strSaveFileName=_T(""), bool bAllowEdit=true, bool bKeepSorted=true, bool bNumeric=false, bool bStoreIndex=false)
   { strSaveFile=strSaveFileName; AllowEdit=bAllowEdit; KeepSorted=bKeepSorted; Numeric=bNumeric; StoreIndex=bStoreIndex; SetSelection(tstrs, iCount); };
   TSelectionInfo(LPCTSTR tstr, const CString& strSaveFileName=_T(""), bool bAllowEdit=true, bool bKeepSorted=true, bool bNumeric=false, bool bStoreIndex=false)
   { strSaveFile=strSaveFileName; AllowEdit=bAllowEdit; KeepSorted=bKeepSorted; Numeric=bNumeric; StoreIndex=bStoreIndex; SetSelection(tstr); };
   TSelectionInfo(const CStringArray& strsArray, const CString& strSaveFileName=_T(""), bool bAllowEdit=true, bool bKeepSorted=true, bool bNumeric=false, bool bStoreIndex=false)
   { strSaveFile=strSaveFileName; AllowEdit=bAllowEdit; KeepSorted=bKeepSorted; Numeric=bNumeric; StoreIndex=bStoreIndex; SetSelection(strsArray); };
   ~TSelectionInfo() {};
   void SetSelection(LPCTSTR tstrs[], int iCount);
   void SetSelection(const CStringArray& strsArray);
   void SetSelection(LPCTSTR tstr);    // null seperated string ex: _T("one\0two\0three\0")
   bool LoadFile();
   bool SaveFile();
   bool AddSelection(CString strName);
   bool RemoveSelection(CString strName);
   bool RemoveAt(int idx);
   bool RemoveAll();
   int FindIndex(const CString& strMatch);
   CString GetAt(int iIndex);
   TStringArray strsSelections;
   bool StoreIndex;
   bool KeepSorted;
   bool AllowEdit;
   bool Numeric;
   CString strSaveFile;
   int GetCount() {return strsSelections.GetSize();}
   void Sort() {Numeric ? strsSelections.SortNumbers() : strsSelections.Sort();}
};
